@@ -4,11 +4,12 @@
 """
 
 __author__ = 'crohaco (crohaco.net@gmail.com)'
-__version__ = '1.1.0'
+__version__ = '1.1.2'
 __license__ = 'PSF License'
 
 from .container.list import ListContainer
 from .container.dict import DictContainer
+from .container.dict import OrderedDictContainer
 
 from .model.list import ListModel
 from .model.dict import DictModel
@@ -19,6 +20,9 @@ from .pattern.cycle import CyclePattern
 from .pattern.hash import HashPattern
 from .pattern.increment import IncrementPattern
 
+# Container is ListContainer
+Container = ListContainer
+
 
 def Model(params):  # NOQA
     if isinstance(params, dict):
