@@ -14,8 +14,13 @@ class CyclePattern(BasePattern):
         :param callback: function to be called at the end of rendering.
         :return: Cycle Pattern instance.
         """
-        self.choices = choices
-        self.size = len(choices)
+        if isinstance(choices, dict):
+            self.choices = []
+            for value, num in choices.items():
+                self.choices += [value] * num
+        else:
+            self.choices = choices
+        self.size = len(self.choices)
         self.index = 0
         self.increment = increment
         self.add_callback(callback)
