@@ -20,7 +20,7 @@ class LimitedChoicePattern(BasePattern):
             for value, num in choices.items():
                 self.choices += [value] * num
         else:
-            self.choices = choices
+            self.choices = list(choices)
         self.missing = missing
         self.add_callback(callback)
 
@@ -32,10 +32,10 @@ class LimitedChoicePattern(BasePattern):
         """
         last_index = len(self.choices) - 1
         if last_index == -1:
-            element = self.missing
-        else:
-            pop_index = randint(0, last_index)
-            element = self.choices.pop(pop_index)
+            return self.missing
+
+        pop_index = randint(0, last_index)
+        element = self.choices.pop(pop_index)
 
         for callback in self.callbacks:
             element = callback(element)
