@@ -15,7 +15,7 @@ class TestLimitedChoicePattern(TestCase):
         for i in range(3):
             self.assertIn(pattern.render(), expect)
 
-        self.assertEqual(pattern.render(), '0')
+        self.assertEqual(pattern.render(), 0)
 
     def test_limited_choices_pattern_receive_dict_choices(self):
         choices = {'a': 1, 'b': 2, 'c': 3}
